@@ -121,6 +121,7 @@ pub fn run(mut args: Opt) -> Result<()> {
 	let mut tags = repository.tags(&config.git.tag_pattern, args.date_order)?;
 
 	// Skip tags.
+	config.git.skip_tags = config.git.skip_tags.filter(|r| !r.as_str().is_empty());
 	let skip_regex = config.git.skip_tags.as_ref();
 	let ignore_regex = config.git.ignore_tags.as_ref();
 	tags = tags
@@ -155,31 +156,36 @@ pub fn run(mut args: Opt) -> Result<()> {
 		}
 	} else if args.latest || args.current {
 		if tags.len() < 2 {
-			return Err(Error::ChangelogError(String::from(
-				"Not enough tags exist for processing the latest/current tag",
-			)));
-		}
-		let mut tag_index = tags.len() - 2;
-		if args.current {
-			if let Some(current_tag_index) =
-				repository.current_tag().as_ref().and_then(|tag| {
-					tags.iter()
-						.enumerate()
-						.find(|(_, (_, v))| v == &tag)
-						.map(|(i, _)| i)
-				}) {
-				tag_index = current_tag_index - 1;
-			} else {
-				return Err(Error::ChangelogError(String::from(
-					"No tag exists for the current commit",
-				)));
+			let commits = repository.commits(None, None, None)?;
+			if let (Some(tag1), Some(tag2)) = (
+				commits.last().map(|c| c.id().to_string()),
+				tags.get_index(0).map(|(k, _)| k),
+			) {
+				commit_range = Some(format!("{}..{}", tag1, tag2));
+			}
+		} else {
+			let mut tag_index = tags.len() - 2;
+			if args.current {
+				if let Some(current_tag_index) =
+					repository.current_tag().as_ref().and_then(|tag| {
+						tags.iter()
+							.enumerate()
+							.find(|(_, (_, v))| v == &tag)
+							.map(|(i, _)| i)
+					}) {
+					tag_index = current_tag_index - 1;
+				} else {
+					return Err(Error::ChangelogError(String::from(
+						"No tag exists for the current commit",
+					)));
+				}
+			}
+			if let (Some(tag1), Some(tag2)) = (
+				tags.get_index(tag_index).map(|(k, _)| k),
+				tags.get_index(tag_index + 1).map(|(k, _)| k),
+			) {
+				commit_range = Some(format!("{}..{}", tag1, tag2));
 			}
-		}
-		if let (Some(tag1), Some(tag2)) = (
-			tags.get_index(tag_index).map(|(k, _)| k),
-			tags.get_index(tag_index + 1).map(|(k, _)| k),
-		) {
-			commit_range = Some(format!("{}..{}", tag1, tag2));
 		}
 	}
 	let commits =
