@@ -14,7 +14,7 @@ if [ -n "$1" ]; then
 	{% for group, commits in commits | group_by(attribute=\"group\") %}
 	{{ group | upper_first }}\
 	{% for commit in commits %}
-		- {{ commit.message | upper_first }} ({{ commit.id | truncate(length=7, end=\"\") }})\
+		- {% if commit.breaking %}(breaking) {% endif %}{{ commit.message | upper_first }} ({{ commit.id | truncate(length=7, end=\"\") }})\
 	{% endfor %}
 	{% endfor %}"
 	changelog=$(cargo run -- --unreleased --strip all)
